@@ -8,9 +8,11 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.gdk.Pixbuf;
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
+import org.gnu.javagnome.Handle;
+
 /**
  * The About widget dialog window is designed to pop up from the
  * About button on an application menu. Its purpose is to standardize
