@@ -8,8 +8,10 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Handle;
+
 import org.gnu.glib.Type;
+import org.gnu.javagnome.Handle;
+
 /**
  * A GnomeCanvasPolygon is a GnomeCanvasItem that draws a filled
  * polygon on a GnomeCanvas.
