@@ -14,12 +14,13 @@ import java.util.Vector;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.FontPickerEvent;
 import org.gnu.gnome.event.FontPickerListener;
 import org.gnu.gtk.Button;
 import org.gnu.gtk.Widget;
+import org.gnu.javagnome.Handle;
+
 /**
  * The FontPicker widget is a button that, when selected, presents
  * a window that enables the user to select from among the many
@@ -167,7 +168,6 @@ public class FontPicker extends Button {
 	// Event handling
 	//////////////////////////////////////////////////////
 
-	// TODO: events doen't seem to be propogated.
 	/**
 	 * Register an object to handle FontPicker events.
 	 * @see org.gnu.gnome.event.FontPickerListener
