@@ -8,12 +8,14 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Handle;
-import org.gnu.gtk.GtkObject;
+
+import org.gnu.glib.GObject;
+import org.gnu.javagnome.Handle;
+
 /**
  *
  */
-public class UIBuilderData extends GtkObject 
+public class UIBuilderData extends GObject 
 {
 	
 	public UIBuilderData(Handle handle) {
