@@ -9,7 +9,7 @@
 
 #include <jni.h>
 #include <gnome.h>
-#include <libgtk-java/jg_jnu.h>
+#include <jg_jnu.h>
 
 #ifdef __cplusplus
 extern "C" 
@@ -43,7 +43,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_UIInfo_uiinfo_1new(JNIEnv *env, jcl
 	cptr->pixmap_type = pixmapType;
 	cptr->accelerator_key = accelKey;
 	cptr->ac_mods = modifierType;
-	
+
     return getHandleFromPointer(env, cptr);
 }
 
@@ -51,7 +51,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_UIInfo_uiinfo_1new(JNIEnv *env, jcl
  * Class:     org_gnu_gnome_UIInfo
  * Method:    setPixmapInfo
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_UIInfo_setPixmapInfo__Lorg_gnu_glib_Handle_2Ljava_lang_String_2
+JNIEXPORT void JNICALL Java_org_gnu_gnome_UIInfo_setPixmapInfo__Lorg_gnu_javagnome_Handle_2Ljava_lang_String_2
   (JNIEnv *env, jclass cls, jobject hndl, jstring data) {
   	GnomeUIInfo *uiinfo = (GnomeUIInfo*)getPointerFromHandle(env, hndl);
     const gchar* data_g = (*env)->GetStringUTFChars(env, data, 0);
@@ -62,7 +62,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_UIInfo_setPixmapInfo__Lorg_gnu_glib_Ha
  * Class:     org_gnu_gnome_UIInfo
  * Method:    setPixmapInfo
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_UIInfo_setPixmapInfo__Lorg_gnu_glib_Handle_2_3B
+JNIEXPORT void JNICALL Java_org_gnu_gnome_UIInfo_setPixmapInfo__Lorg_gnu_javagnome_Handle_2_3B
   (JNIEnv *env, jclass cls, jobject hndl, jbyteArray data) {
   	GnomeUIInfo *uiinfo = (GnomeUIInfo*)getPointerFromHandle(env, hndl);
 	jint data_len = (*env)->GetArrayLength(env, data);
@@ -141,10 +141,11 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_UIInfo_setMoreInfo
 JNIEXPORT void JNICALL Java_org_gnu_gnome_UIInfo_setSubmenuInfo
   (JNIEnv *env, jclass cls, jobject hndl, jobjectArray info)
 {
-  	GnomeUIInfo *uiinfo = (GnomeUIInfo*)getPointerFromHandle(env, hndl);
-	GnomeUIInfo** submenu = (GnomeUIInfo**)getPointerArrayFromHandles(env, info);
-	uiinfo->moreinfo = (gpointer)submenu;
-	uiinfo->user_data = NULL;
+    GnomeUIInfo *uiinfo = (GnomeUIInfo*)getPointerFromHandle(env, hndl);
+    GnomeUIInfo* submenu = (GnomeUIInfo*)getArrayFromHandles(env, info, sizeof(GnomeUIInfo), 1, 0);
+
+    uiinfo->moreinfo = (gpointer)submenu;
+    uiinfo->user_data = NULL;
 }
                                                                                 
 
@@ -290,11 +291,6 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_UIInfo_getAcMods (JNIEnv *env, jclass
     return (jint) (GnomeUIInfo_get_ac_mods (cptr_g));
 }
 
-GtkWidget * GnomeUIInfo_get_widget (GnomeUIInfo * cptr) 
-{
-    return cptr->widget;
-}
-
 /*
  * Class:     org.gnu.gnome.UIInfo
  * Method:    getWidget
@@ -302,7 +298,7 @@ GtkWidget * GnomeUIInfo_get_widget (GnomeUIInfo * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_UIInfo_getWidget (JNIEnv *env, jclass cls, jobject cptr) 
 {
     GnomeUIInfo *cptr_g = (GnomeUIInfo *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeUIInfo_get_widget (cptr_g));
+    return getHandleFromPointer(env, cptr_g->widget);
 }
 
 
